@@ -40,14 +40,19 @@ KAddressBookPart::KAddressBookPart(QWidget *parentWidget, QObject *parent, const
     const WhatsNewTranslations translations;
     const QString newFeaturesMD5 = translations.newFeaturesMD5();
     if (!newFeaturesMD5.isEmpty()) {
-        const bool hasNewFeature = (Settings::self()->previousNewFeaturesMD5() != newFeaturesMD5);
-        if (hasNewFeature) {
-            auto whatsNewMessageWidget = new PimCommon::WhatsNewMessageWidget(parentWidget, i18n("KAddressBook"));
-            whatsNewMessageWidget->setWhatsNewInfos(translations.createWhatsNewInfo());
-            whatsNewMessageWidget->setObjectName(u"whatsNewMessageWidget"_s);
-            topLayout->addWidget(whatsNewMessageWidget);
+        const QString previousNewFeaturesMD5 = Settings::self()->previousNewFeaturesMD5();
+        if (!previousNewFeaturesMD5.isEmpty()) {
+            const bool hasNewFeature = (previousNewFeaturesMD5 != newFeaturesMD5);
+            if (hasNewFeature) {
+                auto whatsNewMessageWidget = new PimCommon::WhatsNewMessageWidget(parentWidget, i18n("KAddressBook"));
+                whatsNewMessageWidget->setWhatsNewInfos(translations.createWhatsNewInfo());
+                whatsNewMessageWidget->setObjectName(u"whatsNewMessageWidget"_s);
+                topLayout->addWidget(whatsNewMessageWidget);
+                Settings::self()->setPreviousNewFeaturesMD5(newFeaturesMD5);
+                whatsNewMessageWidget->animatedShow();
+            }
+        } else {
             Settings::self()->setPreviousNewFeaturesMD5(newFeaturesMD5);
-            whatsNewMessageWidget->animatedShow();
         }
     }
 
